## Community Analysis ####

## load packages
library(data.table)
library(dplyr) #select
library(ggplot2)
library(ggpubr) #geom_signif, ggarrange
library(ggrepel)
library(RColorBrewer)
library(tibble)
library(tidyr)
library(vegan) #decorana
library(scales) #comma

#set working directory here
setwd()

### Set-up the datasets ####################################################################################
### Read in the site data ###
site.data <- readxl::read_excel("Norwood Rowan Faith QSA Supplementary Datasets.xlsx", na = "-",sheet = 'Faunal layer ages')

### Read in the abundance data ###
fauna_abundance <- readxl::read_excel("Norwood Rowan Faith QSA Supplementary Datasets.xlsx", na = "-",sheet = 'Faunal abundance matrix')

### Presence/absence formatted for tally ###

pa.data<- fauna_abundance %>%
  dplyr::select(Species:BNK1_19) %>%
  pivot_longer(names_to="Code", cols=NBC_YGL:BNK1_19)
head(pa.data) ### check it out

# Replace any remaining NAs with zeros
pa.data[is.na(pa.data)] <- 0

# Count unique species present per assemblage
species_count <- pa.data %>%
  filter(value > 0) %>%             # Filter rows where value is greater than 1
  group_by(Code) %>%                 # Group by Code
  summarize(n_species = n_distinct(Species)) # Count unique species

# View the result
species_count

# Filter species_count dataframe and extract codes with NTAXA > 3 as a list
codes_list <- species_count %>%
  filter(n_species > 2) %>%
  pull(Code)

# Print the resulting list
codes_list

#Create subset of fauna_abundance with only those assemblages
filtered_fauna_abundance <- fauna_abundance %>%
  dplyr::select(Order, Family, Species, Diet, Mass.kg, Size.Class, Hempson, all_of(codes_list))

# View the resulting dataframe
head(filtered_fauna_abundance)

#update pa.data with filtered list
pa.data_update <- filtered_fauna_abundance %>%
  dplyr::select(Species:SEH_SA) %>%
  pivot_longer(names_to="Code", cols=BFK_BOL_2:SEH_SA)
head(pa.data_update) ### check it out

### Merge the site and abundance data ###
final.data<-left_join(site.data, pa.data_update)
head(final.data) ### check it out

# Create Site column
final.data <- final.data %>%
  mutate(Site = sub("_.*", "", Code))

### Pollen data ###
pollen <- readxl::read_excel("Norwood Rowan Faith QSA Supplementary Datasets.xlsx", na = "-",sheet = 'Poaceae data')

# Define the levels for the ordered factor
time_levels <- c("3.MIS2/3","4.LGM","5.LGIT","6.EarlyHolocene","7.MidHolocene","8.LateHolocene")

# Create an ordered factor column "Age.Bin"
pollen$Age.Bin <- factor(pollen$Age.Bin, levels = time_levels, ordered = TRUE)

### Faunal DCAS ######

###### Part 1: Tally Hempson categories ##########################################################################

# Remove rows where the Hempson value is NA
fauna_update <- filtered_fauna_abundance %>% filter(Hempson != "NA")
fauna_update <- fauna_update %>% filter(Hempson != "C")
fauna_update[fauna_update == "-"] <- 0

#counts for each functional type for each unit
# List of layer columns
layer_columns <- colnames(fauna_update)[grepl("NBC|BPA|SEH|RCC|BRS|EBC|PL8|BFK|EC|BNK", colnames(fauna_update))]

# Initialize an empty data frame to store the results
results_df <- data.frame()

# Iterate through each layer column
for (layer in layer_columns) {
  # Filter rows where the layer abundance is greater than 0
  filtered_data <- fauna_update %>% filter(.data[[layer]] > 0)
  
  # Count the number of species in each Hempson category
  counts <- filtered_data %>% 
    group_by(Hempson) %>% 
    summarise(count = n()) %>%
    pivot_wider(names_from = Hempson, values_from = count, values_fill = list(count = 0)) %>%
    mutate(Layer = layer)
  
  # Bind the result to the results data frame
  results_df <- bind_rows(results_df, counts)
}

# Reorder columns to have Layer as the first column
results_df <- results_df %>% dplyr::select(Layer, everything())

# Replace any remaining NAs with zeros
results_df[is.na(results_df)] <- 0

# Print the results
print(results_df)
### looks good

# Remove rows with all zero values
results_df <- results_df[rowSums(results_df[, -(1)]) > 0, ]


###### Part 2: Detrended Correspondence Analysis ##########################################################################

# Perform DCA
dca_result_fauna <- decorana(results_df[, -(1)])  # Exclude non-species columns

#ordination
# Plot DCA
par(mfrow=c(1,1))
plot(dca_result_fauna)

summary(dca_result_fauna)

####Extract site scores
faunasitescores <- scores(dca_result_fauna,
                          display= "sites")

faunasitescores <- as.data.frame(faunasitescores)
faunasitescores$Code <- results_df$Layer

fauna_scores <- merge(faunasitescores, site.data, by = "Code", 
                      all.x = TRUE)

fauna_scores$Age <- as.numeric(fauna_scores$Age)

fauna_scores$Age.Bin <- as.factor(fauna_scores$Age.Bin)

##look at loadings 
faunatypescores <- scores(dca_result_fauna,
                          display= "species")

faunatypescores <- as.data.frame(faunatypescores)

faunatypescores$Label <- c("A", "D", "E", "B")

# Display the first few rows of the updated dataset
head(fauna_scores)
#looks good

# Add a new column with the first three letters of the 'Code' column
fauna_scores$CodePrefix <- substr(fauna_scores$Code, 1, 3)
# Replace "EC_" with "EC" in the CodePrefix column
fauna_scores$CodePrefix <- gsub("EC_", "EC", fauna_scores$CodePrefix)

# Define the custom colors
custom_colors <- c("#c0e361", "#a6b9d8", "#c290e9", "#edd6a0", "#eba34d", "#d1644f")

# Create the plot to avoid overlap between text and lines without moving the text too far
ggplot(fauna_scores, aes(x = DCA1, y = DCA2, label = CodePrefix, color = Age.Bin)) +
  geom_text_repel(size = 5, fontface = "bold", 
                  max.overlaps = Inf,  # Allow for maximum number of text labels
                  box.padding = 0.2,  # Small space around the text box
                  point.padding = 0.1,  # Small space around the original points
                  min.segment.length = 0.1,  # Keep lines short
                  segment.size = 0.3,  # Thin line segments
                  segment.color = 'grey50',  # Line color
                  segment.alpha = 0.7,  # Slight transparency to reduce visual clutter
                  force = 0.5,  # Moderate force to repel labels without pushing too far
                  direction = "both",  # Allow labels to be repelled in all directions
                  max.time = 2,  # Max time to find optimal positions
                  max.iter = 5000,  # Max iterations for finding best positions
                  segment.curvature = 0) +  # Straight lines
  labs(x = "DCA1", y = "DCA2", color = "Age Bin") +
  scale_color_manual(values = custom_colors) +  # Use custom colors
  theme_bw() +
  theme(legend.position = "right") +
  geom_text_repel(data = faunatypescores, aes(x = DCA1, y = DCA2, label = Label), 
                  color = "black", size = 7, fontface = "bold", 
                  box.padding = 0.2, 
                  point.padding = 0.2, 
                  segment.size = 0.3, 
                  segment.color = 'grey50', 
                  segment.alpha = 0.7, 
                  force = 0.5, 
                  direction = "both", 
                  max.time = 2, 
                  max.iter = 5000, 
                  segment.curvature = 0)  # Straight lines

##### Part 3: Calculate z-score ###########################################################

# Group by 'Site' and calculate mean and standard deviation of DCA1
site_stats <- fauna_scores %>%
  group_by(Site) %>%
  summarise(
    mean_DCA1 = mean(DCA1, na.rm = TRUE),
    sd_DCA1 = sd(DCA1, na.rm = TRUE)
  )

# Join the site_stats back to the original data frame
fauna_scores <- fauna_scores %>%
  left_join(site_stats, by = "Site")

# Calculate the z-scores for DCA1
fauna_scores <- fauna_scores %>%
  mutate(z = (DCA1 - mean_DCA1) / sd_DCA1)

# Display the first few rows of the updated dataset
head(fauna_scores)
#looks good

##### Part 4: Significance tests ####

# Perform the Shapiro-Wilk test for each Age bin
shapiro_results_dca <- fauna_scores %>%
  group_by(Age.Bin) %>%
  summarize(shapiro_p_value = shapiro.test(z)$p.value)

# View the results
print(shapiro_results_dca)
#p-values are high, meaning values are normally distributed

# Perform one-way ANOVA
anova_result_dca <- aov(z ~ Age.Bin, data = fauna_scores)
# Display the summary of the ANOVA
summary(anova_result_dca)

# Perform Tukey's HSD test
tukey_result_dca <- TukeyHSD(anova_result_dca)

# Display the results
print(tukey_result_dca)

# Extract significant pairs from Tukey's test
significant_pairs_dca <- as.data.frame(tukey_result_dca$Age.Bin)

# Add row names as a new column for comparison pairs
significant_pairs_dca <- significant_pairs_dca %>%
  rownames_to_column(var = "Comparison")

# Filter to keep only significant comparisons
significant_pairs_dca <- significant_pairs_dca %>%
  filter(`p adj` < 0.05)

# Extract the significant pairs for plotting
comparisons_list_dca <- strsplit(significant_pairs_dca$Comparison, "-")

ggplot(fauna_scores, aes(x = Age.Bin, y = z)) +
  geom_boxplot() +
  xlab("Age") +
  ylab("dca z") +
  geom_signif(
    comparisons = comparisons_list_dca,
    map_signif_level = TRUE,
    step_increase = 0.1) +
  scale_x_discrete(breaks = c("3.MIS2/3","4.LGM","5.LGIT","6.EarlyHolocene","7.MidHolocene","8.LateHolocene"), 
                   labels = c("MIS2/3","LGM","LGIT","Early Holocene","Mid Holocene", "Late Holocene")) +
  theme(axis.text.x = element_text(angle = 15, hjust=0.45))

###### Part 5: Visualizations #######################################################################

ggplot(data = fauna_scores) +
  geom_vline(xintercept = 26500, color = "grey25") +
  geom_vline(xintercept = 19000, color = "grey25") +
  geom_vline(xintercept = 11700, color = "grey25") +
  geom_vline(xintercept = 8000, color = "grey25") +
  geom_vline(xintercept = 4000, color = "grey25") +
  geom_point(aes(x = Age, y = z, color = Site)) +
  geom_line(aes(x = Age, y = z, color = Site)) +
  geom_smooth(aes(x = Age, y = z), method = "loess", color = "black") +
  ylab("dca z")  +
  scale_x_reverse(limits = c(50000, 0)) +
  #scale_y_continuous(labels = NULL) +
  scale_color_brewer(palette = "Paired") +
  theme_bw() +
  theme(axis.text.x = element_blank(),
        axis.ticks.x = element_blank(),
        axis.title.x = element_blank())


### Grazer Z scores #####

###### Part 1: Tally traits ##########################################################################
final.data.filtered <- final.data %>% dplyr::select(-`MNI Ref`, -Notes)

### Diet ###
diet.tally<-na.omit(final.data.filtered) %>%
  group_by(Code, Diet) %>%
  summarize(N=sum(value)) %>%
  mutate(Prop=N/sum(N))
head(diet.tally)
diet.cast<- reshape2::dcast(diet.tally, formula=Code~Diet)

##### Part 2: Calculate z-score ###########################################################

# Create Site column
diet.cast <- diet.cast %>%
  mutate(Site = sub("_.*", "", Code))

# Group by 'Site' and calculate mean and standard deviation of grazer proportion
site_grazer_stats <- diet.cast %>%
  group_by(Site) %>%
  summarise(
    mean_gr = mean(gr, na.rm = TRUE),
    sd_gr = sd(gr, na.rm = TRUE)
  )

# Join the site_stats back to the original data frame
grazer_scores <- diet.cast %>%
  left_join(site_grazer_stats, by = "Site")

# Calculate the z-scores for grazer proportion
grazer_scores <- grazer_scores %>%
  mutate(z = (gr - mean_gr) / sd_gr)

# Display the first few rows of the updated dataset
head(grazer_scores)
#looks good

grazer_scores <- merge(grazer_scores, site.data, by = "Code", 
                      all.x = TRUE)

grazer_scores$Age <- as.numeric(grazer_scores$Age)

grazer_scores$Age.Bin <- as.factor(grazer_scores$Age.Bin)

grazer_scores$z <- as.numeric(grazer_scores$z)


##### Part 3: Significance tests ####

# Perform the Shapiro-Wilk test for each Age bin
shapiro_results_grazer <- grazer_scores %>%
  group_by(Age.Bin) %>%
  summarize(shapiro_p_value = shapiro.test(z)$p.value)

# View the results
print(shapiro_results_grazer)
#p-values are high, meaning values are normally distributed

# Perform one-way ANOVA
anova_result_grazer <- aov(z ~ Age.Bin, data = grazer_scores)
# Display the summary of the ANOVA
summary(anova_result_grazer)

# Perform Tukey's HSD test
tukey_result_grazer <- TukeyHSD(anova_result_grazer)

# Display the results
print(tukey_result_grazer)

# Extract significant pairs from Tukey's test
significant_pairs_grazer <- as.data.frame(tukey_result_grazer$Age.Bin)

# Add row names as a new column for comparison pairs
significant_pairs_grazer <- significant_pairs_grazer %>%
  rownames_to_column(var = "Comparison")

# Filter to keep only significant comparisons
significant_pairs_grazer <- significant_pairs_grazer %>%
  filter(`p adj` < 0.05)

# Extract the significant pairs for plotting
comparisons_list <- strsplit(significant_pairs_grazer$Comparison, "-")

ggplot(grazer_scores, aes(x = Age.Bin, y = z)) +
  geom_boxplot() +
  xlab("Age") +
  ylab("grazer z") +
  geom_signif(
    comparisons = comparisons_list,
    map_signif_level = TRUE,
    step_increase = 0.1) +
  scale_x_discrete(breaks = c("3.MIS2/3","4.LGM","5.LGIT","6.EarlyHolocene","7.MidHolocene","8.LateHolocene"), 
                   labels = c("MIS2/3","LGM","LGIT","Early Holocene","Mid Holocene", "Late Holocene")) +
  theme(axis.text.x = element_text(angle = 15, hjust=0.45))

###### Part 4: Visualizations #######################################################################

ggplot(data = grazer_scores) +
  geom_vline(xintercept = 26500, color = "grey25") +
  geom_vline(xintercept = 19000, color = "grey25") +
  geom_vline(xintercept = 11700, color = "grey25") +
  geom_vline(xintercept = 8000, color = "grey25") +
  geom_vline(xintercept = 4000, color = "grey25") +
  geom_point(aes(x = Age, y = z, color = Site.y)) +
  geom_line(aes(x = Age, y = z, color = Site.y)) +
  geom_smooth(aes(x = Age, y = z), method = "loess", color = "black") +
  scale_color_discrete(name = "Site") +
  ylab("grazer z") +
  scale_x_reverse(limits = c(50000, 0)) +
  scale_color_brewer(palette = "Paired") +
  theme_bw() +
  theme(axis.text.x = element_blank(),
        axis.ticks.x = element_blank(),
        axis.title.x = element_blank())

### Sampling bias tests #####

# Merge the datasets on 'Code'
sampling <- diet.cast %>%
  dplyr::select(Code, gr) %>% # Select 'Code' and 'gr' from diet.cast
  inner_join(fauna_scores %>% dplyr::select(Code, DCA1), by = "Code") # Add 'DCA1' from fauna_scores

# View the resulting dataframe
head(sampling)

##Add ages
sampling <- merge(sampling, site.data[, c("Code", "Age", "n_species", "MNI")], by = "Code", all.x = TRUE)

# View the resulting dataframe
head(sampling)

write.csv(sampling, file = "count_summary.csv")


###### Spearman's Correlation Coefficient ######################################################

#for dca axis 1
nDCAcorr <- cor.test(x=sampling$DCA1, y=sampling$n_species, method = 'spearman')

nDCAcorr

MNIDCAcorr <- cor.test(x=sampling$DCA1, y=sampling$MNI, method = 'spearman')

MNIDCAcorr

#for grazer proportions
ngrcorr <- cor.test(x=sampling$gr, y=sampling$n_species, method = 'spearman')

ngrcorr

MNIgrcorr <- cor.test(x=sampling$gr, y=sampling$MNI, method = 'spearman')

MNIgrcorr

### Pollen #####

##### Part 1: Calculate z-score #########################

# Group by 'Site' and calculate mean and standard deviation of DCA1
pollen_site_stats <- pollen %>%
  group_by(Site) %>%
  summarise(
    mean_Poaceae = mean(Poaceae, na.rm = TRUE),
    sd_Poaceae = sd(Poaceae, na.rm = TRUE)
  )

# Join the site_stats back to the original data frame
pollen <- pollen %>%
  left_join(pollen_site_stats, by = "Site")

# Calculate the z-scores for DCA1
pollen <- pollen %>%
  mutate(z = (Poaceae - mean_Poaceae) / sd_Poaceae)

# Display the first few rows of the updated dataset
head(pollen)
#looks good

#Plot all together
ggplot(data = pollen) +
  geom_point(aes(x = Age_ka, y = z, color = Site)) +
  geom_line(aes(x = Age_ka, y = z, color = Site)) +
  ylab("Poaceae z") +
  xlab("Age") +
  scale_x_continuous(
    breaks = c(0,10,20,30,40,50),
    labels = c("0","10,000","20,000","30,000","40,000","50,000")) +
  theme_bw()

p <- ggplot(data = pollen) +
  geom_point(aes(x = Age_ka, y = z, color = Site)) +
  geom_line(aes(x = Age_ka, y = z, color = Site)) +
  ylab("Poaceae z") +
  xlab("Age") +
  geom_smooth(aes(x = Age_ka, y = z), method = "loess", color = "black") + 
  scale_x_continuous(
    breaks = c(0,10,20,30,40,50),
    labels = c("0","10,000","20,000","30,000","40,000","50,000")) +
  theme_bw()

p
##### Part 2: Significance tests ##################

# Perform the Shapiro-Wilk test for each Age bin
shapiro_results_pollen <- pollen %>%
  group_by(Age.Bin) %>%
  summarize(shapiro_p_value = shapiro.test(z)$p.value)

# View the results
print(shapiro_results)
#p-values are high, meaning values are normally distributed

# Perform one-way ANOVA
anova_result_pollen <- aov(z ~ Age.Bin, data = pollen)
# Display the summary of the ANOVA
summary(anova_result_pollen)

# Perform Tukey's HSD test
tukey_result_pollen <- TukeyHSD(anova_result_pollen)

# Display the results
print(tukey_result_pollen)

# Extract significant pairs from Tukey's test
significant_pairs_pollen <- as.data.frame(tukey_result_pollen$Age.Bin)

# Add row names as a new column for comparison pairs
significant_pairs_pollen <- significant_pairs_pollen %>%
  rownames_to_column(var = "Comparison")

# Filter to keep only significant comparisons
significant_pairs_pollen <- significant_pairs_pollen %>%
  filter(`p adj` < 0.05)

# Extract the significant pairs for plotting
comparisons_list_pollen <- strsplit(significant_pairs_pollen$Comparison, "-")

ggplot(pollen, aes(x = Age.Bin, y = z)) +
  geom_boxplot() +
  xlab("Age") +
  ylab("Poaceae z") +
  geom_signif(
    comparisons = comparisons_list_pollen,
    map_signif_level = TRUE,
    step_increase = 0.1) +
  scale_x_discrete(breaks = c("3.MIS2/3","4.LGM","5.LGIT","6.EarlyHolocene","7.MidHolocene","8.LateHolocene"), 
                   labels = c("MIS2/3","LGM","LGIT","Early Holocene","Mid Holocene", "Late Holocene")) +
  theme(axis.text.x = element_text(angle = 15, hjust=0.45))

###### Part 3: Visualizations #######################################################################

ggplot(data = pollen) +
  geom_vline(xintercept = 26.5, color = "grey25") +
  geom_vline(xintercept = 19, color = "grey25") +
  geom_vline(xintercept = 11.7, color = "grey25") +
  geom_vline(xintercept = 8, color = "grey25") +
  geom_vline(xintercept = 4, color = "grey25") +
  geom_point(aes(x = Age_ka, y = z, color = Site)) +
  geom_line(aes(x = Age_ka, y = z, color = Site)) +
  ylab("Poaceae z") +
  xlab("Age") +
  geom_smooth(aes(x = Age_ka, y = z), method = "loess", color = "black") + 
  scale_x_reverse(
    limits = c(50,0)) +
  theme_bw()
